#[repr(i32)]pub enum CoinSelectionStrategy {
StrategyUseGlobalConfig = 0,
StrategyLargest = 1,
StrategyRandom = 2,
}Variants
StrategyUseGlobalConfig = 0
Use the coin selection strategy defined in the global configuration (lnd.conf).
StrategyLargest = 1
Select the largest available coins first during coin selection.
StrategyRandom = 2
Randomly select the available coins during coin selection.
Implementations
Sourceimpl CoinSelectionStrategy
impl CoinSelectionStrategy
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of CoinSelectionStrategy.
Sourcepub fn from_i32(value: i32) -> Option<CoinSelectionStrategy>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<CoinSelectionStrategy>
Converts an i32 to a CoinSelectionStrategy, or None if value is not a valid variant.
Sourceimpl CoinSelectionStrategy
impl CoinSelectionStrategy
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.