#[repr(i32)]pub enum FeatureBit {
Show 27 variants
DatalossProtectReq = 0,
DatalossProtectOpt = 1,
InitialRouingSync = 3,
UpfrontShutdownScriptReq = 4,
UpfrontShutdownScriptOpt = 5,
GossipQueriesReq = 6,
GossipQueriesOpt = 7,
TlvOnionReq = 8,
TlvOnionOpt = 9,
ExtGossipQueriesReq = 10,
ExtGossipQueriesOpt = 11,
StaticRemoteKeyReq = 12,
StaticRemoteKeyOpt = 13,
PaymentAddrReq = 14,
PaymentAddrOpt = 15,
MppReq = 16,
MppOpt = 17,
WumboChannelsReq = 18,
WumboChannelsOpt = 19,
AnchorsReq = 20,
AnchorsOpt = 21,
AnchorsZeroFeeHtlcReq = 22,
AnchorsZeroFeeHtlcOpt = 23,
RouteBlindingRequired = 24,
RouteBlindingOptional = 25,
AmpReq = 30,
AmpOpt = 31,
}Variants
DatalossProtectReq = 0
DatalossProtectOpt = 1
InitialRouingSync = 3
UpfrontShutdownScriptReq = 4
UpfrontShutdownScriptOpt = 5
GossipQueriesReq = 6
GossipQueriesOpt = 7
TlvOnionReq = 8
TlvOnionOpt = 9
ExtGossipQueriesReq = 10
ExtGossipQueriesOpt = 11
StaticRemoteKeyReq = 12
StaticRemoteKeyOpt = 13
PaymentAddrReq = 14
PaymentAddrOpt = 15
MppReq = 16
MppOpt = 17
WumboChannelsReq = 18
WumboChannelsOpt = 19
AnchorsReq = 20
AnchorsOpt = 21
AnchorsZeroFeeHtlcReq = 22
AnchorsZeroFeeHtlcOpt = 23
RouteBlindingRequired = 24
RouteBlindingOptional = 25
AmpReq = 30
AmpOpt = 31
Implementations
Sourceimpl FeatureBit
impl FeatureBit
Sourceimpl FeatureBit
impl FeatureBit
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.