#[repr(i32)]pub enum ResolutionOutcome {
OutcomeUnknown = 0,
Claimed = 1,
Unclaimed = 2,
Abandoned = 3,
FirstStage = 4,
Timeout = 5,
}Variants
OutcomeUnknown = 0
Outcome unknown.
Claimed = 1
An output was claimed on chain.
Unclaimed = 2
An output was left unclaimed on chain.
Abandoned = 3
ResolverOutcomeAbandoned indicates that an output that we did not claim on chain, for example an anchor that we did not sweep and a third party claimed on chain, or a htlc that we could not decode so left unclaimed.
FirstStage = 4
If we force closed our channel, our htlcs need to be claimed in two stages. This outcome represents the broadcast of a timeout or success transaction for this two stage htlc claim.
Timeout = 5
A htlc was timed out on chain.
Implementations
Sourceimpl ResolutionOutcome
impl ResolutionOutcome
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.