#[repr(i32)]pub enum FailureCode {
Show 29 variants
Reserved = 0,
IncorrectOrUnknownPaymentDetails = 1,
IncorrectPaymentAmount = 2,
FinalIncorrectCltvExpiry = 3,
FinalIncorrectHtlcAmount = 4,
FinalExpiryTooSoon = 5,
InvalidRealm = 6,
ExpiryTooSoon = 7,
InvalidOnionVersion = 8,
InvalidOnionHmac = 9,
InvalidOnionKey = 10,
AmountBelowMinimum = 11,
FeeInsufficient = 12,
IncorrectCltvExpiry = 13,
ChannelDisabled = 14,
TemporaryChannelFailure = 15,
RequiredNodeFeatureMissing = 16,
RequiredChannelFeatureMissing = 17,
UnknownNextPeer = 18,
TemporaryNodeFailure = 19,
PermanentNodeFailure = 20,
PermanentChannelFailure = 21,
ExpiryTooFar = 22,
MppTimeout = 23,
InvalidOnionPayload = 24,
InvalidOnionBlinding = 25,
InternalFailure = 997,
UnknownFailure = 998,
UnreadableFailure = 999,
}Variants
Reserved = 0
The numbers assigned in this enumeration match the failure codes as defined in BOLT #4. Because protobuf 3 requires enums to start with 0, a RESERVED value is added.
IncorrectOrUnknownPaymentDetails = 1
IncorrectPaymentAmount = 2
FinalIncorrectCltvExpiry = 3
FinalIncorrectHtlcAmount = 4
FinalExpiryTooSoon = 5
InvalidRealm = 6
ExpiryTooSoon = 7
InvalidOnionVersion = 8
InvalidOnionHmac = 9
InvalidOnionKey = 10
AmountBelowMinimum = 11
FeeInsufficient = 12
IncorrectCltvExpiry = 13
ChannelDisabled = 14
TemporaryChannelFailure = 15
RequiredNodeFeatureMissing = 16
RequiredChannelFeatureMissing = 17
UnknownNextPeer = 18
TemporaryNodeFailure = 19
PermanentNodeFailure = 20
PermanentChannelFailure = 21
ExpiryTooFar = 22
MppTimeout = 23
InvalidOnionPayload = 24
InvalidOnionBlinding = 25
InternalFailure = 997
An internal error occurred.
UnknownFailure = 998
The error source is known, but the failure itself couldn’t be decoded.
UnreadableFailure = 999
An unreadable failure result is returned if the received failure message cannot be decrypted. In that case the error source is unknown.
Implementations
Sourceimpl FailureCode
impl FailureCode
Sourceimpl FailureCode
impl FailureCode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.