pub struct BatchOpenChannelRequest {
pub channels: Vec<BatchOpenChannel>,
pub target_conf: i32,
pub sat_per_vbyte: i64,
pub min_confs: i32,
pub spend_unconfirmed: bool,
pub label: String,
pub coin_selection_strategy: i32,
}Fields
channels: Vec<BatchOpenChannel>The list of channels to open.
target_conf: i32The target number of blocks that the funding transaction should be confirmed by.
sat_per_vbyte: i64A manual fee rate set in sat/vByte that should be used when crafting the funding transaction.
min_confs: i32The minimum number of confirmations each one of your outputs used for the funding transaction must satisfy.
spend_unconfirmed: boolWhether unconfirmed outputs should be used as inputs for the funding transaction.
label: StringAn optional label for the batch transaction, limited to 500 characters.
coin_selection_strategy: i32The strategy to use for selecting coins during batch opening channels.
Implementations
Sourceimpl BatchOpenChannelRequest
impl BatchOpenChannelRequest
Sourcepub fn coin_selection_strategy(&self) -> CoinSelectionStrategy
pub fn coin_selection_strategy(&self) -> CoinSelectionStrategy
Returns the enum value of coin_selection_strategy, or the default if the field is set to an invalid enum value.
Sourcepub fn set_coin_selection_strategy(&mut self, value: CoinSelectionStrategy)
pub fn set_coin_selection_strategy(&mut self, value: CoinSelectionStrategy)
Sets coin_selection_strategy to the provided enum value.