BlindedPathConfig

Struct BlindedPathConfig 

pub struct BlindedPathConfig {
    pub min_num_real_hops: Option<u32>,
    pub num_hops: Option<u32>,
    pub max_num_paths: Option<u32>,
    pub node_omission_list: Vec<Vec<u8>>,
    pub incoming_channel_list: Vec<u64>,
}

Fields

min_num_real_hops: Option<u32>

The minimum number of real hops to include in a blinded path. This doesn’t include our node, so if the minimum is 1, then the path will contain at minimum our node along with an introduction node hop. If it is zero then the shortest path will use our node as an introduction node.

num_hops: Option<u32>

The number of hops to include in a blinded path. This doesn’t include our node, so if it is 1, then the path will contain our node along with an introduction node or dummy node hop. If paths shorter than NumHops is found, then they will be padded using dummy hops.

max_num_paths: Option<u32>

The maximum number of blinded paths to select and add to an invoice.

node_omission_list: Vec<Vec<u8>>

A list of node IDs of nodes that should not be used in any of our generated blinded paths.

incoming_channel_list: Vec<u64>

The chained channels list specified via channel id (separated by commas), starting from a channel owned by the receiver node.

Implementations

Source

impl BlindedPathConfig

pub fn min_num_real_hops(&self) -> u32

Returns the value of min_num_real_hops, or the default value if min_num_real_hops is unset.

pub fn num_hops(&self) -> u32

Returns the value of num_hops, or the default value if num_hops is unset.

pub fn max_num_paths(&self) -> u32

Returns the value of max_num_paths, or the default value if max_num_paths is unset.