pub struct ChannelAuthProof {
pub node_sig1: Vec<u8>,
pub bitcoin_sig1: Vec<u8>,
pub node_sig2: Vec<u8>,
pub bitcoin_sig2: Vec<u8>,
}Expand description
ChannelAuthProof is the authentication proof (the signature portion) for a channel. Using the four signatures contained in the struct, and some auxiliary knowledge (the funding script, node identities, and outpoint) nodes on the network are able to validate the authenticity and existence of a channel.
Fields
node_sig1: Vec<u8>node_sig1 are the raw bytes of the first node signature encoded in DER format.
bitcoin_sig1: Vec<u8>bitcoin_sig1 are the raw bytes of the first bitcoin signature of the MultiSigKey key of the channel encoded in DER format.
node_sig2: Vec<u8>node_sig2 are the raw bytes of the second node signature encoded in DER format.
bitcoin_sig2: Vec<u8>bitcoin_sig2 are the raw bytes of the second bitcoin signature of the MultiSigKey key of the channel encoded in DER format.