pub struct ChannelCloseUpdate {
pub closing_txid: Vec<u8>,
pub success: bool,
pub local_close_output: Option<CloseOutput>,
pub remote_close_output: Option<CloseOutput>,
pub additional_outputs: Vec<CloseOutput>,
}Fields
closing_txid: Vec<u8>success: boollocal_close_output: Option<CloseOutput>The local channel close output. If the local channel balance was dust to begin with, this output will not be set.
remote_close_output: Option<CloseOutput>The remote channel close output. If the remote channel balance was dust to begin with, this output will not be set.
additional_outputs: Vec<CloseOutput>Any additional outputs that might be added for custom channel types.