pub struct ChannelEventUpdate {
pub type: i32,
pub channel: Option<Channel>,
}Fields
type: i32channel: Option<Channel>Implementations
Sourceimpl ChannelEventUpdate
impl ChannelEventUpdate
Sourcepub fn type(&self) -> UpdateType
pub fn type(&self) -> UpdateType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: UpdateType)
pub fn set_type(&mut self, value: UpdateType)
Sets type to the provided enum value.