pub struct ChannelGraphRequest {
pub include_unannounced: bool,
pub include_auth_proof: bool,
}Fields
include_unannounced: boolWhether unannounced channels are included in the response or not. If set, unannounced channels are included. Unannounced channels are both private channels, and public channels that are not yet announced to the network.
include_auth_proof: boolIf true, will include announcements’ signatures into ChannelEdge.