CloseChannelRequest

Struct CloseChannelRequest 

pub struct CloseChannelRequest {
    pub channel_point: Option<ChannelPoint>,
    pub force: bool,
    pub target_conf: i32,
    pub sat_per_byte: i64,
    pub delivery_address: String,
    pub sat_per_vbyte: u64,
    pub max_fee_per_vbyte: u64,
    pub no_wait: bool,
}

Fields

channel_point: Option<ChannelPoint>

The outpoint (txid:index) of the funding transaction. With this value, Bob will be able to generate a signature for Alice’s version of the commitment transaction.

force: bool

If true, then the channel will be closed forcibly. This means the current commitment transaction will be signed and broadcast.

target_conf: i32

The target number of blocks that the closure transaction should be confirmed by.

sat_per_byte: i64
👎Deprecated

Deprecated, use sat_per_vbyte. A manual fee rate set in sat/vbyte that should be used when crafting the closure transaction.

delivery_address: String

An optional address to send funds to in the case of a cooperative close. If the channel was opened with an upfront shutdown script and this field is set, the request to close will fail because the channel must pay out to the upfront shutdown addresss.

sat_per_vbyte: u64

A manual fee rate set in sat/vbyte that should be used when crafting the closure transaction.

max_fee_per_vbyte: u64

The maximum fee rate the closer is willing to pay.

NOTE: This field is only respected if we’re the initiator of the channel.

no_wait: bool

If true, then the rpc call will not block while it awaits a closing txid to be broadcasted to the mempool. To obtain the closing tx one has to listen to the stream for the particular updates. Moreover if a coop close is specified and this flag is set to true the coop closing flow will be initiated even if HTLCs are active on the channel. The channel will wait until all HTLCs are resolved and then start the coop closing process. The channel will be disabled in the meantime and will disallow any new HTLCs.