pub struct CloseOutput {
pub amount_sat: i64,
pub pk_script: Vec<u8>,
pub is_local: bool,
pub custom_channel_data: Vec<u8>,
}Fields
amount_sat: i64The amount in satoshi of this close output. This amount is the final commitment balance of the channel and the actual amount paid out on chain might be smaller due to subtracted fees.
pk_script: Vec<u8>The pkScript of the close output.
is_local: boolWhether this output is for the local or remote node.
custom_channel_data: Vec<u8>The TLV encoded custom channel data records for this output, which might be set for custom channels.