PolicyUpdateRequest

Struct PolicyUpdateRequest 

pub struct PolicyUpdateRequest {
    pub base_fee_msat: i64,
    pub fee_rate: f64,
    pub fee_rate_ppm: u32,
    pub time_lock_delta: u32,
    pub max_htlc_msat: u64,
    pub min_htlc_msat: u64,
    pub min_htlc_msat_specified: bool,
    pub inbound_fee: Option<InboundFee>,
    pub create_missing_edge: bool,
    pub scope: Option<Scope>,
}

Fields

base_fee_msat: i64

The base fee charged regardless of the number of milli-satoshis sent.

fee_rate: f64

The effective fee rate in milli-satoshis. The precision of this value goes up to 6 decimal places, so 1e-6.

fee_rate_ppm: u32

The effective fee rate in micro-satoshis (parts per million).

time_lock_delta: u32

The required timelock delta for HTLCs forwarded over the channel.

max_htlc_msat: u64

If set, the maximum HTLC size in milli-satoshis. If unset, the maximum HTLC will be unchanged.

min_htlc_msat: u64

The minimum HTLC size in milli-satoshis. Only applied if min_htlc_msat_specified is true.

min_htlc_msat_specified: bool

If true, min_htlc_msat is applied.

inbound_fee: Option<InboundFee>

Optional inbound fee. If unset, the previously set value will be retained [EXPERIMENTAL].

create_missing_edge: bool

Under unknown circumstances a channel can exist with a missing edge in the graph database. This can cause an ‘edge not found’ error when calling getchaninfo and/or cause the default channel policy to be used during forwards. Setting this flag will recreate the edge if not found, allowing updating this channel policy and fixing the missing edge problem for this channel permanently. For fields not set in this command, the default policy will be created.

scope: Option<Scope>