pub struct RpcMessage {
pub method_full_uri: String,
pub stream_rpc: bool,
pub type_name: String,
pub serialized: Vec<u8>,
pub is_error: bool,
}Fields
method_full_uri: StringThe full URI (in the format /
stream_rpc: boolIndicates whether the message was sent over a streaming RPC method or not.
type_name: StringThe full canonical gRPC name of the message type (in the format
serialized: Vec<u8>The full content of the gRPC message, serialized in the binary protobuf format.
is_error: boolIndicates that the response from lnd was an error, not a gRPC response. If this is set to true then the type_name contains the string “error” and serialized contains the error string.