pub struct SendManyRequest {
pub addr_to_amount: HashMap<String, i64>,
pub target_conf: i32,
pub sat_per_vbyte: u64,
pub sat_per_byte: i64,
pub label: String,
pub min_confs: i32,
pub spend_unconfirmed: bool,
pub coin_selection_strategy: i32,
}Fields
addr_to_amount: HashMap<String, i64>The map from addresses to amounts
target_conf: i32The target number of blocks that this transaction should be confirmed by.
sat_per_vbyte: u64A manual fee rate set in sat/vbyte that should be used when crafting the transaction.
sat_per_byte: i64Deprecated, use sat_per_vbyte. A manual fee rate set in sat/vbyte that should be used when crafting the transaction.
label: StringAn optional label for the transaction, limited to 500 characters.
min_confs: i32The minimum number of confirmations each one of your outputs used for the transaction must satisfy.
spend_unconfirmed: boolWhether unconfirmed outputs should be used as inputs for the transaction.
coin_selection_strategy: i32The strategy to use for selecting coins during sending many requests.
Implementations
Sourceimpl SendManyRequest
impl SendManyRequest
Sourcepub fn coin_selection_strategy(&self) -> CoinSelectionStrategy
pub fn coin_selection_strategy(&self) -> CoinSelectionStrategy
Returns the enum value of coin_selection_strategy, or the default if the field is set to an invalid enum value.
Sourcepub fn set_coin_selection_strategy(&mut self, value: CoinSelectionStrategy)
pub fn set_coin_selection_strategy(&mut self, value: CoinSelectionStrategy)
Sets coin_selection_strategy to the provided enum value.