pub struct SendToRouteRequest {
pub payment_hash: Vec<u8>,
pub payment_hash_string: String,
pub route: Option<Route>,
}Fields
payment_hash: Vec<u8>The payment hash to use for the HTLC. When using REST, this field must be encoded as base64.
payment_hash_string: String👎Deprecated
An optional hex-encoded payment hash to be used for the HTLC. Deprecated now that the REST gateway supports base64 encoding of bytes fields.
route: Option<Route>Route that should be used to attempt to complete the payment.