pub struct Transaction {
pub tx_hash: String,
pub amount: i64,
pub num_confirmations: i32,
pub block_hash: String,
pub block_height: i32,
pub time_stamp: i64,
pub total_fees: i64,
pub dest_addresses: Vec<String>,
pub output_details: Vec<OutputDetail>,
pub raw_tx_hex: String,
pub label: String,
pub previous_outpoints: Vec<PreviousOutPoint>,
}Fields
tx_hash: StringThe transaction hash
amount: i64The transaction amount, denominated in satoshis
num_confirmations: i32The number of confirmations
block_hash: StringThe hash of the block this transaction was included in
block_height: i32The height of the block this transaction was included in
time_stamp: i64Timestamp of this transaction
total_fees: i64Fees paid for this transaction
dest_addresses: Vec<String>👎Deprecated
Addresses that received funds for this transaction. Deprecated as it is now incorporated in the output_details field.
output_details: Vec<OutputDetail>Outputs that received funds for this transaction
raw_tx_hex: StringThe raw transaction hex.
label: StringA label that was optionally set on transaction broadcast.
previous_outpoints: Vec<PreviousOutPoint>PreviousOutpoints/Inputs of this transaction.