pub struct VerifyMessageRequest {
pub msg: Vec<u8>,
pub signature: String,
}Fields
msg: Vec<u8>The message over which the signature is to be verified. When using REST, this field must be encoded as base64.
signature: StringThe signature to be verified over the given message