pub struct BatchOpenChannel {Show 20 fields
pub node_pubkey: Vec<u8>,
pub local_funding_amount: i64,
pub push_sat: i64,
pub private: bool,
pub min_htlc_msat: i64,
pub remote_csv_delay: u32,
pub close_address: String,
pub pending_chan_id: Vec<u8>,
pub commitment_type: i32,
pub remote_max_value_in_flight_msat: u64,
pub remote_max_htlcs: u32,
pub max_local_csv: u32,
pub zero_conf: bool,
pub scid_alias: bool,
pub base_fee: u64,
pub fee_rate: u64,
pub use_base_fee: bool,
pub use_fee_rate: bool,
pub remote_chan_reserve_sat: u64,
pub memo: String,
}Fields
node_pubkey: Vec<u8>The pubkey of the node to open a channel with. When using REST, this field must be encoded as base64.
local_funding_amount: i64The number of satoshis the wallet should commit to the channel.
push_sat: i64The number of satoshis to push to the remote side as part of the initial commitment state.
private: boolWhether this channel should be private, not announced to the greater network.
min_htlc_msat: i64The minimum value in millisatoshi we will require for incoming HTLCs on the channel.
remote_csv_delay: u32The delay we require on the remote’s commitment transaction. If this is not set, it will be scaled automatically with the channel size.
close_address: StringClose address is an optional address which specifies the address to which funds should be paid out to upon cooperative close. This field may only be set if the peer supports the option upfront feature bit (call listpeers to check). The remote peer will only accept cooperative closes to this address if it is set.
Note: If this value is set on channel creation, you will not be able to cooperatively close out to a different address.
pending_chan_id: Vec<u8>An optional, unique identifier of 32 random bytes that will be used as the pending channel ID to identify the channel while it is in the pre-pending state.
commitment_type: i32The explicit commitment type to use. Note this field will only be used if the remote peer supports explicit channel negotiation.
remote_max_value_in_flight_msat: u64The maximum amount of coins in millisatoshi that can be pending within the channel. It only applies to the remote party.
remote_max_htlcs: u32The maximum number of concurrent HTLCs we will allow the remote party to add to the commitment transaction.
max_local_csv: u32Max local csv is the maximum csv delay we will allow for our own commitment transaction.
zero_conf: boolIf this is true, then a zero-conf channel open will be attempted.
scid_alias: boolIf this is true, then an option-scid-alias channel-type open will be attempted.
base_fee: u64The base fee charged regardless of the number of milli-satoshis sent.
fee_rate: u64The fee rate in ppm (parts per million) that will be charged in proportion of the value of each forwarded HTLC.
use_base_fee: boolIf use_base_fee is true the open channel announcement will update the channel base fee with the value specified in base_fee. In the case of a base_fee of 0 use_base_fee is needed downstream to distinguish whether to use the default base fee value specified in the config or 0.
use_fee_rate: boolIf use_fee_rate is true the open channel announcement will update the channel fee rate with the value specified in fee_rate. In the case of a fee_rate of 0 use_fee_rate is needed downstream to distinguish whether to use the default fee rate value specified in the config or 0.
remote_chan_reserve_sat: u64The number of satoshis we require the remote peer to reserve. This value, if specified, must be above the dust limit and below 20% of the channel capacity.
memo: StringAn optional note-to-self to go along with the channel containing some useful information. This is only ever stored locally and in no way impacts the channel’s operation.
Implementations
Sourceimpl BatchOpenChannel
impl BatchOpenChannel
Sourcepub fn commitment_type(&self) -> CommitmentType
pub fn commitment_type(&self) -> CommitmentType
Returns the enum value of commitment_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_commitment_type(&mut self, value: CommitmentType)
pub fn set_commitment_type(&mut self, value: CommitmentType)
Sets commitment_type to the provided enum value.