InvoiceSubscription

Struct InvoiceSubscription 

pub struct InvoiceSubscription {
    pub add_index: u64,
    pub settle_index: u64,
}

Fields

add_index: u64

If specified (non-zero), then we’ll first start by sending out notifications for all added indexes with an add_index greater than this value. This allows callers to catch up on any events they missed while they weren’t connected to the streaming RPC.

settle_index: u64

If specified (non-zero), then we’ll first start by sending out notifications for all settled indexes with an settle_index greater than this value. This allows callers to catch up on any events they missed while they weren’t connected to the streaming RPC.