pub struct OpenChannelRequest {Show 28 fields
pub sat_per_vbyte: u64,
pub node_pubkey: Vec<u8>,
pub node_pubkey_string: String,
pub local_funding_amount: i64,
pub push_sat: i64,
pub target_conf: i32,
pub sat_per_byte: i64,
pub private: bool,
pub min_htlc_msat: i64,
pub remote_csv_delay: u32,
pub min_confs: i32,
pub spend_unconfirmed: bool,
pub close_address: String,
pub funding_shim: Option<FundingShim>,
pub remote_max_value_in_flight_msat: u64,
pub remote_max_htlcs: u32,
pub max_local_csv: u32,
pub commitment_type: i32,
pub zero_conf: bool,
pub scid_alias: bool,
pub base_fee: u64,
pub fee_rate: u64,
pub use_base_fee: bool,
pub use_fee_rate: bool,
pub remote_chan_reserve_sat: u64,
pub fund_max: bool,
pub memo: String,
pub outpoints: Vec<OutPoint>,
}Fields
sat_per_vbyte: u64A manual fee rate set in sat/vbyte that should be used when crafting the funding transaction.
node_pubkey: Vec<u8>The pubkey of the node to open a channel with. When using REST, this field must be encoded as base64.
node_pubkey_string: StringThe hex encoded pubkey of the node to open a channel with. Deprecated now that the REST gateway supports base64 encoding of bytes fields.
local_funding_amount: i64The number of satoshis the wallet should commit to the channel
push_sat: i64The number of satoshis to push to the remote side as part of the initial commitment state
target_conf: i32The target number of blocks that the funding transaction should be confirmed by.
sat_per_byte: i64Deprecated, use sat_per_vbyte. A manual fee rate set in sat/vbyte that should be used when crafting the funding transaction.
private: boolWhether this channel should be private, not announced to the greater network.
min_htlc_msat: i64The minimum value in millisatoshi we will require for incoming HTLCs on the channel.
remote_csv_delay: u32The delay we require on the remote’s commitment transaction. If this is not set, it will be scaled automatically with the channel size.
min_confs: i32The minimum number of confirmations each one of your outputs used for the funding transaction must satisfy.
spend_unconfirmed: boolWhether unconfirmed outputs should be used as inputs for the funding transaction.
close_address: StringClose address is an optional address which specifies the address to which funds should be paid out to upon cooperative close. This field may only be set if the peer supports the option upfront feature bit (call listpeers to check). The remote peer will only accept cooperative closes to this address if it is set.
Note: If this value is set on channel creation, you will not be able to cooperatively close out to a different address.
funding_shim: Option<FundingShim>Funding shims are an optional argument that allow the caller to intercept certain funding functionality. For example, a shim can be provided to use a particular key for the commitment key (ideally cold) rather than use one that is generated by the wallet as normal, or signal that signing will be carried out in an interactive manner (PSBT based).
remote_max_value_in_flight_msat: u64The maximum amount of coins in millisatoshi that can be pending within the channel. It only applies to the remote party.
remote_max_htlcs: u32The maximum number of concurrent HTLCs we will allow the remote party to add to the commitment transaction.
max_local_csv: u32Max local csv is the maximum csv delay we will allow for our own commitment transaction.
commitment_type: i32The explicit commitment type to use. Note this field will only be used if the remote peer supports explicit channel negotiation.
zero_conf: boolIf this is true, then a zero-conf channel open will be attempted.
scid_alias: boolIf this is true, then an option-scid-alias channel-type open will be attempted.
base_fee: u64The base fee charged regardless of the number of milli-satoshis sent.
fee_rate: u64The fee rate in ppm (parts per million) that will be charged in proportion of the value of each forwarded HTLC.
use_base_fee: boolIf use_base_fee is true the open channel announcement will update the channel base fee with the value specified in base_fee. In the case of a base_fee of 0 use_base_fee is needed downstream to distinguish whether to use the default base fee value specified in the config or 0.
use_fee_rate: boolIf use_fee_rate is true the open channel announcement will update the channel fee rate with the value specified in fee_rate. In the case of a fee_rate of 0 use_fee_rate is needed downstream to distinguish whether to use the default fee rate value specified in the config or 0.
remote_chan_reserve_sat: u64The number of satoshis we require the remote peer to reserve. This value, if specified, must be above the dust limit and below 20% of the channel capacity.
fund_max: boolIf set, then lnd will attempt to commit all the coins under control of the internal wallet to open the channel, and the LocalFundingAmount field must be zero and is ignored.
memo: StringAn optional note-to-self to go along with the channel containing some useful information. This is only ever stored locally and in no way impacts the channel’s operation.
outpoints: Vec<OutPoint>A list of selected outpoints that are allocated for channel funding.
Implementations
Sourceimpl OpenChannelRequest
impl OpenChannelRequest
Sourcepub fn commitment_type(&self) -> CommitmentType
pub fn commitment_type(&self) -> CommitmentType
Returns the enum value of commitment_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_commitment_type(&mut self, value: CommitmentType)
pub fn set_commitment_type(&mut self, value: CommitmentType)
Sets commitment_type to the provided enum value.