pub struct PolicyUpdateRequest {
pub base_fee_msat: i64,
pub fee_rate: f64,
pub fee_rate_ppm: u32,
pub time_lock_delta: u32,
pub max_htlc_msat: u64,
pub min_htlc_msat: u64,
pub min_htlc_msat_specified: bool,
pub inbound_fee: Option<InboundFee>,
pub create_missing_edge: bool,
pub scope: Option<Scope>,
}Fields
base_fee_msat: i64The base fee charged regardless of the number of milli-satoshis sent.
fee_rate: f64The effective fee rate in milli-satoshis. The precision of this value goes up to 6 decimal places, so 1e-6.
fee_rate_ppm: u32The effective fee rate in micro-satoshis (parts per million).
time_lock_delta: u32The required timelock delta for HTLCs forwarded over the channel.
max_htlc_msat: u64If set, the maximum HTLC size in milli-satoshis. If unset, the maximum HTLC will be unchanged.
min_htlc_msat: u64The minimum HTLC size in milli-satoshis. Only applied if min_htlc_msat_specified is true.
min_htlc_msat_specified: boolIf true, min_htlc_msat is applied.
inbound_fee: Option<InboundFee>Optional inbound fee. If unset, the previously set value will be retained [EXPERIMENTAL].
create_missing_edge: boolUnder unknown circumstances a channel can exist with a missing edge in
the graph database. This can cause an ‘edge not found’ error when calling
getchaninfo and/or cause the default channel policy to be used during
forwards. Setting this flag will recreate the edge if not found, allowing
updating this channel policy and fixing the missing edge problem for this
channel permanently. For fields not set in this command, the default
policy will be created.
scope: Option<Scope>Trait Implementations
Sourceimpl Clone for PolicyUpdateRequest
impl Clone for PolicyUpdateRequest
Sourcefn clone(&self) -> PolicyUpdateRequest
fn clone(&self) -> PolicyUpdateRequest
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for PolicyUpdateRequest
impl Debug for PolicyUpdateRequest
Sourceimpl Default for PolicyUpdateRequest
impl Default for PolicyUpdateRequest
Sourceimpl Message for PolicyUpdateRequest
impl Message for PolicyUpdateRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
self.Sourceimpl PartialEq for PolicyUpdateRequest
impl PartialEq for PolicyUpdateRequest
impl StructuralPartialEq for PolicyUpdateRequest