pub struct Resolution {
pub resolution_type: i32,
pub outcome: i32,
pub outpoint: Option<OutPoint>,
pub amount_sat: u64,
pub sweep_txid: String,
}Fields
resolution_type: i32The type of output we are resolving.
outcome: i32The outcome of our on chain action that resolved the outpoint.
outpoint: Option<OutPoint>The outpoint that was spent by the resolution.
amount_sat: u64The amount that was claimed by the resolution.
sweep_txid: StringThe hex-encoded transaction ID of the sweep transaction that spent the output.
Implementations
Sourceimpl Resolution
impl Resolution
Sourcepub fn resolution_type(&self) -> ResolutionType
pub fn resolution_type(&self) -> ResolutionType
Returns the enum value of resolution_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_resolution_type(&mut self, value: ResolutionType)
pub fn set_resolution_type(&mut self, value: ResolutionType)
Sets resolution_type to the provided enum value.
Sourcepub fn outcome(&self) -> ResolutionOutcome
pub fn outcome(&self) -> ResolutionOutcome
Returns the enum value of outcome, or the default if the field is set to an invalid enum value.
Sourcepub fn set_outcome(&mut self, value: ResolutionOutcome)
pub fn set_outcome(&mut self, value: ResolutionOutcome)
Sets outcome to the provided enum value.