pub struct RpcMiddlewareRequest {
pub request_id: u64,
pub raw_macaroon: Vec<u8>,
pub custom_caveat_condition: String,
pub msg_id: u64,
pub metadata_pairs: HashMap<String, MetadataValues>,
pub intercept_type: Option<InterceptType>,
}Fields
request_id: u64The unique ID of the intercepted original gRPC request. Useful for mapping request to response when implementing full duplex message interception. For streaming requests, this will be the same ID for all incoming and outgoing middleware intercept messages of the same stream.
raw_macaroon: Vec<u8>The raw bytes of the complete macaroon as sent by the gRPC client in the original request. This might be empty for a request that doesn’t require macaroons such as the wallet unlocker RPCs.
custom_caveat_condition: StringThe parsed condition of the macaroon’s custom caveat for convenient access. This field only contains the value of the custom caveat that the handling middleware has registered itself for. The condition must be validated for messages of intercept_type stream_auth and request!
msg_id: u64The unique message ID of this middleware intercept message. There can be multiple middleware intercept messages per single gRPC request (one for the incoming request and one for the outgoing response) or gRPC stream (one for each incoming message and one for each outgoing response). This message ID must be referenced when responding (accepting/rejecting/modifying) to an intercept message.
metadata_pairs: HashMap<String, MetadataValues>The metadata pairs that were sent along with the original gRPC request via the golang context.Context using explicit gRPC metadata. Context values are not propagated via gRPC and so we send any pairs along explicitly here so that the interceptor can access them.
intercept_type: Option<InterceptType>There are three types of messages that will be sent to the middleware for inspection and approval: Stream authentication, request and response interception. The first two can only be accepted (=forward to main RPC server) or denied (=return error to client). Intercepted responses can also be replaced/overwritten.