SendCustomMessageRequest

Struct SendCustomMessageRequest 

pub struct SendCustomMessageRequest {
    pub peer: Vec<u8>,
    pub type: u32,
    pub data: Vec<u8>,
}

Fields

peer: Vec<u8>

Peer to send the message to

type: u32

Message type. This value needs to be in the custom range (>= 32768). To send a type < custom range, lnd needs to be compiled with the dev build tag, and the message type to override should be specified in lnd’s experimental protocol configuration.

data: Vec<u8>

Raw message data.