pub struct SendRequest {Show 16 fields
pub dest: Vec<u8>,
pub dest_string: String,
pub amt: i64,
pub amt_msat: i64,
pub payment_hash: Vec<u8>,
pub payment_hash_string: String,
pub payment_request: String,
pub final_cltv_delta: i32,
pub fee_limit: Option<FeeLimit>,
pub outgoing_chan_id: u64,
pub last_hop_pubkey: Vec<u8>,
pub cltv_limit: u32,
pub dest_custom_records: HashMap<u64, Vec<u8>>,
pub allow_self_payment: bool,
pub dest_features: Vec<i32>,
pub payment_addr: Vec<u8>,
}Fields
dest: Vec<u8>The identity pubkey of the payment recipient. When using REST, this field must be encoded as base64.
dest_string: StringThe hex-encoded identity pubkey of the payment recipient. Deprecated now that the REST gateway supports base64 encoding of bytes fields.
amt: i64The amount to send expressed in satoshis.
The fields amt and amt_msat are mutually exclusive.
amt_msat: i64The amount to send expressed in millisatoshis.
The fields amt and amt_msat are mutually exclusive.
payment_hash: Vec<u8>The hash to use within the payment’s HTLC. When using REST, this field must be encoded as base64.
payment_hash_string: StringThe hex-encoded hash to use within the payment’s HTLC. Deprecated now that the REST gateway supports base64 encoding of bytes fields.
payment_request: StringA bare-bones invoice for a payment within the Lightning Network. With the details of the invoice, the sender has all the data necessary to send a payment to the recipient.
final_cltv_delta: i32The CLTV delta from the current height that should be used to set the timelock for the final hop.
fee_limit: Option<FeeLimit>The maximum number of satoshis that will be paid as a fee of the payment. This value can be represented either as a percentage of the amount being sent, or as a fixed amount of the maximum fee the user is willing the pay to send the payment. If not specified, lnd will use a default value of 100% fees for small amounts (<=1k sat) or 5% fees for larger amounts.
outgoing_chan_id: u64The channel id of the channel that must be taken to the first hop. If zero, any channel may be used.
last_hop_pubkey: Vec<u8>The pubkey of the last hop of the route. If empty, any hop may be used.
cltv_limit: u32An optional maximum total time lock for the route. This should not exceed
lnd’s --max-cltv-expiry setting. If zero, then the value of
--max-cltv-expiry is enforced.
dest_custom_records: HashMap<u64, Vec<u8>>An optional field that can be used to pass an arbitrary set of TLV records to a peer which understands the new records. This can be used to pass application specific data during the payment attempt. Record types are required to be in the custom range >= 65536. When using REST, the values must be encoded as base64.
allow_self_payment: boolIf set, circular payments to self are permitted.
dest_features: Vec<i32>Features assumed to be supported by the final node. All transitive feature dependencies must also be set properly. For a given feature bit pair, either optional or remote may be set, but not both. If this field is nil or empty, the router will try to load destination features from the graph as a fallback.
payment_addr: Vec<u8>The payment address of the generated invoice. This is also called payment secret in specifications (e.g. BOLT 11).
Implementations
Sourceimpl SendRequest
impl SendRequest
Sourcepub fn dest_features(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<FeatureBit>>
pub fn dest_features( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<FeatureBit>>
Returns an iterator which yields the valid enum values contained in dest_features.
Sourcepub fn push_dest_features(&mut self, value: FeatureBit)
pub fn push_dest_features(&mut self, value: FeatureBit)
Appends the provided enum value to dest_features.